version_info = (0, 8, 11, 5)

__version__ = version = '.'.join(map(str, version_info))
__project__ = PROJECT = 'django-summernote'
__author__ = AUTHOR = "django-summernote contributors"


default_app_config = 'django_summernote.apps.DjangoSummernoteConfig'
