<!DOCTYPE html>
<html>
    <head>
        <title>django-summernote frame</title>
        {% for url in css %}
        <link href="{{ url }}" rel="stylesheet">{% endfor %}
        {% for url in js %}
        <script src="{{ url }}"></script>{% endfor %}
        <style>
        html, body {
            margin: 0;
        }
        .note-editor {
            margin-bottom: 0;
        }
        </style>
    </head>
    <body>
        <div id="summernote"></div>
    </body>
    {% include "django_summernote/widget_common.html" with iframe=True %}
    <script>
    initSummernote_{{ id_safe }}();
    </script>
</html>
