<script>
var settings_{{ id_safe }} = {{ settings|safe }};
</script>
<style>
iframe.note-fullscreen {
  position: fixed;
  top: 0;
  left: 0;
  width: 100vw!important;
  height: 100vh!important;
  z-index: 4000;
}
</style>
<div class="summernote-div" {{ flat_attrs }} width="{{ width }}" height="{{ height }}">
  <iframe id="{{ id }}_iframe" src="{{ src }}" frameborder="0" width="{{ width }}" height="{{ height }}"></iframe>
</div>
