# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-11 07:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_summernote', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='name',
            field=models.CharField(blank=True, help_text='Defaults to filename, if left blank', max_length=255, null=True),
        ),
    ]
