{% include "django_summernote/widget_common.html" with iframe=False %}
<script>
{% if config.lazy %}
    if( __summernotes__ === undefined ) {
        var __summernotes__ = new Array();
        function initSummernote() {
            for (i = 0, l = __summernotes__.length; i < l; ++i) {
                __summernotes__[i]();
            }
        }
    }
    __summernotes__.push(initSummernote_{{ id_safe }});
{% else %}
    initSummernote_{{ id_safe }}();
{% endif %}
</script>
